@@ -34,8 +34,8 @@ NNS.dep.hd <- function (x, plot = FALSE, independence.overlay = FALSE){
         colnames(A) <- c(colnames.list)
     }
 
-    A_upm <- apply(A, 2, function(x) x > median(x))
-    A_lpm <- apply(A, 2, function(x) x <= median(x))
+    A_upm <- apply(A, 2, function(x) x > gravity(x))
+    A_lpm <- apply(A, 2, function(x) x <= gravity(x))
 
     upm_prods <- RP(A_upm)
     lpm_prods <- RP(A_lpm)
@@ -52,8 +52,8 @@ NNS.dep.hd <- function (x, plot = FALSE, independence.overlay = FALSE){
     if(plot && n == 3){
 
         rgl::plot3d(x = A[ , 1], y = A[ , 2], z = A[ , 3], box = FALSE, size = 3,
-           col=ifelse((A[ , 1] <= median(A[ , 1])) & (A[ , 2] <= median(A[ , 2])) & (A[ , 3] <= median(A[ , 3])), 'red' ,
-                      ifelse((A[ , 1] > median(A[ , 1])) & (A[ , 2] > median(A[ , 2])) & (A[ , 3] > median(A[ , 3])), 'green',
+           col=ifelse((A[ , 1] <= gravity(A[ , 1])) & (A[ , 2] <= gravity(A[ , 2])) & (A[ , 3] <= gravity(A[ , 3])), 'red' ,
+                      ifelse((A[ , 1] > gravity(A[ , 1])) & (A[ , 2] > gravity(A[ , 2])) & (A[ , 3] > gravity(A[ , 3])), 'green',
                       'steelblue')), xlab = colnames(A)[1], ylab = colnames(A)[2], zlab = colnames(A)[3])
 
         if(independence.overlay == TRUE){
@@ -64,16 +64,16 @@ NNS.dep.hd <- function (x, plot = FALSE, independence.overlay = FALSE){
             clpm.box$vb[1, ] <- replace(clpm.box$vb[1, ], clpm.box$vb[1, ] == -1, min(A[ , 1]))
             clpm.box$vb[2, ] <- replace(clpm.box$vb[2, ], clpm.box$vb[2, ] == -1, min(A[ , 2]))
             clpm.box$vb[3, ] <- replace(clpm.box$vb[3, ], clpm.box$vb[3, ] == -1, min(A[ , 3]))
-            clpm.box$vb[1, ] <- replace(clpm.box$vb[1, ], clpm.box$vb[1, ] == 1, median(A[, 1]))
-            clpm.box$vb[2, ] <- replace(clpm.box$vb[2, ], clpm.box$vb[2, ] == 1, median(A[, 2]))
-            clpm.box$vb[3, ] <- replace(clpm.box$vb[3, ], clpm.box$vb[3, ] == 1, median(A[, 3]))
+            clpm.box$vb[1, ] <- replace(clpm.box$vb[1, ], clpm.box$vb[1, ] == 1, gravity(A[, 1]))
+            clpm.box$vb[2, ] <- replace(clpm.box$vb[2, ], clpm.box$vb[2, ] == 1, gravity(A[, 2]))
+            clpm.box$vb[3, ] <- replace(clpm.box$vb[3, ], clpm.box$vb[3, ] == 1, gravity(A[, 3]))
 
             cupm.box$vb[1, ] <- replace(cupm.box$vb[1, ], cupm.box$vb[1, ] == 1, max(A[ , 1]))
             cupm.box$vb[2, ] <- replace(cupm.box$vb[2, ], cupm.box$vb[2, ] == 1, max(A[ , 2]))
             cupm.box$vb[3, ] <- replace(cupm.box$vb[3, ], cupm.box$vb[3, ] == 1, max(A[ , 3]))
-            cupm.box$vb[1, ] <- replace(cupm.box$vb[1, ], cupm.box$vb[1, ] == -1, median(A[, 1]))
-            cupm.box$vb[2, ] <- replace(cupm.box$vb[2, ], cupm.box$vb[2, ] == -1, median(A[, 2]))
-            cupm.box$vb[3, ] <- replace(cupm.box$vb[3, ], cupm.box$vb[3, ] == -1, median(A[, 3]))
+            cupm.box$vb[1, ] <- replace(cupm.box$vb[1, ], cupm.box$vb[1, ] == -1, gravity(A[, 1]))
+            cupm.box$vb[2, ] <- replace(cupm.box$vb[2, ], cupm.box$vb[2, ] == -1, gravity(A[, 2]))
+            cupm.box$vb[3, ] <- replace(cupm.box$vb[3, ], cupm.box$vb[3, ] == -1, gravity(A[, 3]))
 
 
             rgl::shade3d(clpm.box)
