@@ -71,7 +71,16 @@ dy.d_<- function(x, y, wrt,
 
 
   if(is.null(l)) stop("Please ensure (x) is a matrix or data.frame type object.")
-  if(l<2) stop("Please use dy.dx(...) for univariate partial derivatives.")
+  if(l < 2) stop("Please use dy.dx(...) for univariate partial derivatives.")
+
+  if(is.null(colnames(x))){
+    colnames.list <- list()
+    for(i in 1 : l){
+      colnames.list[i] <- paste0("X", i)
+    }
+    colnames(x) <- as.character(colnames.list)
+  }
+
 
   if(NNS.dep.hd(cbind(x, y))$Dependence > 0.25) h <- 0.2 else h <- max(0.1, 1/exp(l-2))
 
@@ -110,60 +119,62 @@ dy.d_<- function(x, y, wrt,
   }
 
   if(is.vector(eval.points) || dim(eval.points)[2] == 1){
-        eval.points <- unlist(eval.points)
+    eval.points <- unlist(eval.points)
 
-        h_step <- LPM.ratio(1, eval.points, x[, wrt])
-        h_step <- LPM.VaR(h_step + h, 1, x[, wrt]) - LPM.VaR(h_step - h, 1, x[, wrt])
+    h_step <- LPM.ratio(1, eval.points, x[, wrt])
+    h_step <- LPM.VaR(h_step + h, 1, x[, wrt]) - LPM.VaR(h_step - h, 1, x[, wrt])
 
-        original.eval.points.min <- original.eval.points.min - h_step
-        original.eval.points.max <- h_step + original.eval.points.max
+    original.eval.points.min <- original.eval.points.min - h_step
+    original.eval.points.max <- h_step + original.eval.points.max
 
-        deriv.points <- apply(x, 2, function(z) LPM.VaR(seq(0,1,.05), 0, z))
+    deriv.points <- apply(x, 2, function(z) LPM.VaR(seq(0,1,.05), 0, z))
 
-        if(dim(deriv.points)[2]!=dim(x)[2]){
-              deriv.points <- matrix(deriv.points, ncol = l, byrow = FALSE)
-        }
+    if(dim(deriv.points)[2]!=dim(x)[2]){
+      deriv.points <- matrix(deriv.points, ncol = l, byrow = FALSE)
+    }
 
 
-        sampsize <- length(seq(0,1,.05))
+    sampsize <- length(seq(0,1,.05))
 
-        deriv.points <- data.table::data.table(do.call(rbind, replicate(3*length(eval.points), deriv.points, simplify = FALSE)))
+    deriv.points <- data.table::data.table(do.call(rbind, replicate(3*length(eval.points), deriv.points, simplify = FALSE)))
 
-        data.table::set(deriv.points, i=NULL, j = wrt, value = rep(unlist(rbind(original.eval.points.min,
-                                                                                eval.points,
-                                                                                original.eval.points.max))
-                                                                      , each = sampsize, length.out = dim(deriv.points)[1] ))
-        colnames(deriv.points) <- colnames(x)
-
-        distance_wrt <- 2 * h_step
-
-        position <- rep(rep(c("l", "m", "u"), each = sampsize), length.out = dim(deriv.points)[1])
-        id <- rep(1:length(eval.points), each = 3*sampsize, length.out = dim(deriv.points)[1])
+    data.table::set(deriv.points, i=NULL, j = wrt, value = rep(unlist(rbind(original.eval.points.min,
+                                                                            eval.points,
+                                                                            original.eval.points.max))
+                                                               , each = sampsize, length.out = dim(deriv.points)[1] ))
 
 
-      if(messages){
-          message(paste("Currently evaluating the ", dim(deriv.points)[1], " required points"  ),"\r",appendLF=TRUE)
-      }
+    colnames(deriv.points) <- colnames(x)
 
-        estimates <- NNS.reg(x, y, point.est = deriv.points, dim.red.method = "equal", plot = FALSE, threshold = 0, order = order)$Point.est
+    distance_wrt <- 2 * h_step
 
-        estimates <- data.table::data.table(cbind(estimates = estimates,
-                                                  position = position,
-                                                  id = id))
+    position <- rep(rep(c("l", "m", "u"), each = sampsize), length.out = dim(deriv.points)[1])
+    id <- rep(1:length(eval.points), each = 3*sampsize, length.out = dim(deriv.points)[1])
 
-        lower_msd <- estimates[position=="l", sapply(.SD, function(x) list(mean=mean(as.numeric(x)), sd=sd(as.numeric(x)))), .SDcols = "estimates", by = id]
-        lower <- lower_msd$V1
-        lower_sd <- lower_msd$V2
 
-        fx_msd <- estimates[position=="m", sapply(.SD, function(x) list(mean=mean(as.numeric(x)), sd=sd(as.numeric(x)))), .SDcols = "estimates", by = id]
-        two.f.x <- 2* fx_msd$V1
-        two.f.x_sd <- fx_msd$V2
+    if(messages){
+      message(paste("Currently evaluating the ", dim(deriv.points)[1], " required points"  ),"\r",appendLF=TRUE)
+    }
 
-        upper_msd <- estimates[position=="u", sapply(.SD, function(x) list(mean=mean(as.numeric(x)), sd=sd(as.numeric(x)))), .SDcols = "estimates", by = id]
-        upper <- upper_msd$V1
-        upper_msd <- upper_msd$V2
+    estimates <- NNS.reg(x, y, point.est = deriv.points, dim.red.method = "equal", plot = FALSE, threshold = 0, order = order)$Point.est
 
-        rise <- upper - lower
+    estimates <- data.table::data.table(cbind(estimates = estimates,
+                                              position = position,
+                                              id = id))
+
+    lower_msd <- estimates[position=="l", sapply(.SD, function(x) list(mean=mean(as.numeric(x)), sd=sd(as.numeric(x)))), .SDcols = "estimates", by = id]
+    lower <- lower_msd$V1
+    lower_sd <- lower_msd$V2
+
+    fx_msd <- estimates[position=="m", sapply(.SD, function(x) list(mean=mean(as.numeric(x)), sd=sd(as.numeric(x)))), .SDcols = "estimates", by = id]
+    two.f.x <- 2* fx_msd$V1
+    two.f.x_sd <- fx_msd$V2
+
+    upper_msd <- estimates[position=="u", sapply(.SD, function(x) list(mean=mean(as.numeric(x)), sd=sd(as.numeric(x)))), .SDcols = "estimates", by = id]
+    upper <- upper_msd$V1
+    upper_msd <- upper_msd$V2
+
+    rise <- upper - lower
 
   } else {
     n <- dim(eval.points)[1]
@@ -176,8 +187,8 @@ dy.d_<- function(x, y, wrt,
     original.eval.points.max[ , wrt] <- h_step + original.eval.points.max[ , wrt]
 
     deriv.points <- rbind(original.eval.points.min,
-                                  original.eval.points,
-                                  original.eval.points.max)
+                          original.eval.points,
+                          original.eval.points.max)
 
     estimates <- NNS.reg(x, y, point.est = deriv.points, dim.red.method = "equal", plot = FALSE, threshold = 0, order = order)$Point.est
 
